@@ -25,7 +25,7 @@
 #include "utils.h"
 #include "gm_crypt.h"
 #include "base64.h"
-#include "gearman.h"
+#include "gearman_utils.h"
 #include "popenRWE.h"
 #include "polarssl/md5.h"
 
@@ -139,11 +139,13 @@ int mod_gm_encrypt(char ** encrypted, char * text, int mode) {
 
 /* decrypt text with given key */
 void mod_gm_decrypt(char ** decrypted, char * text, int mode) {
+    char *test;
     unsigned char * buffer = malloc(sizeof(unsigned char) * GM_BUFFERSIZE);
 
     /* first decode from base64 */
     size_t bsize = base64_decode(text, buffer, GM_BUFFERSIZE);
-    if(mode == GM_ENCODE_AND_ENCRYPT) {
+    test = strndup(buffer, 5);
+    if(mode == GM_ENCODE_AND_ENCRYPT || (mode == GM_ENCODE_ACCEPT_ALL && strcmp(test, "type="))) {
         /* then decrypt */
         mod_gm_aes_decrypt(decrypted, buffer, bsize);
     }
@@ -153,6 +155,7 @@ void mod_gm_decrypt(char ** decrypted, char * text, int mode) {
         debase64[bsize] = '\0';
         strcpy(*decrypted, debase64);
     }
+    free(test);
     free(buffer);
     return;
 }
@@ -249,9 +252,12 @@ int set_default_options(mod_gm_opt_t *opt) {
     opt->max_jobs           = GM_DEFAULT_MAX_JOBS;
     opt->spawn_rate         = GM_DEFAULT_SPAWN_RATE;
     opt->identifier         = NULL;
+    opt->queue_cust_var     = NULL;
     opt->show_error_output  = GM_ENABLED;
-    opt->orphan_host_checks    = GM_ENABLED;
-    opt->orphan_service_checks = GM_ENABLED;
+    opt->dup_results_are_passive = GM_ENABLED;
+    opt->orphan_host_checks      = GM_ENABLED;
+    opt->orphan_service_checks   = GM_ENABLED;
+    opt->accept_clear_results    = GM_DISABLED;
 
     opt->workaround_rc_25   = GM_DISABLED;
 
@@ -324,8 +330,15 @@ int parse_yes_or_no(char*value, int dfl) {
 
 /* parse one line of args into the given struct */
 int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
+    int i, x, number, callback_num;
     char *key;
     char *value;
+    char *callback;
+    char *export_queue;
+    char *return_code;
+    int return_code_num;
+    char *callbacks;
+    char * type;
 
     gm_log( GM_LOG_TRACE, "parse_args_line(%s, %d)\n", arg, recursion_level);
 
@@ -415,6 +428,12 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
         return(GM_OK);
     }
 
+    /* dup_results_are_passive */
+    else if ( !strcmp( key, "dup_results_are_passive" ) ) {
+        opt->dup_results_are_passive = parse_yes_or_no(value, GM_ENABLED);
+        return(GM_OK);
+    }
+
     /* workaround_rc_25 */
     else if ( !strcmp( key, "workaround_rc_25" ) ) {
         opt->workaround_rc_25 = parse_yes_or_no(value, GM_ENABLED);
@@ -433,6 +452,12 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
         return(GM_OK);
     }
 
+    /* accept_clear_results */
+    else if ( !strcmp( key, "accept_clear_results" ) ) {
+        opt->accept_clear_results = parse_yes_or_no(value, GM_ENABLED);
+        return(GM_OK);
+    }
+
     /* enable_embedded_perl */
     else if ( !strcmp( key, "enable_embedded_perl" ) ) {
 #ifdef EMBEDDEDPERL
@@ -615,7 +640,7 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
     /* max-age */
     else if ( !strcmp( key, "max-age" ) ) {
         opt->max_age = atoi( value );
-        if(opt->max_age <= 0) { opt->max_age = 1; }
+        if(opt->max_age < 0) { opt->max_age = GM_DEFAULT_JOB_MAX_AGE; }
     }
 
     /* idle-timeout */
@@ -725,26 +750,32 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
         }
     }
 
+    /* queue_custom_variable */
+    else if ( !strcmp( key, "queue_custom_variable" ) ) {
+        /* uppercase custom variable name */
+        for(x = 0; value[x] != '\x0'; x++) {
+            value[x] = toupper(value[x]);
+        }
+        opt->queue_cust_var = strdup( value );
+    }
+
     /* export queues */
     else if ( !strcmp( key, "export" ) ) {
-        char *callback;
-        char *export_queue;
         export_queue        = strsep( &value, ":" );
         export_queue        = trim(export_queue);
-        char *return_code   = strsep( &value, ":" );
-        int return_code_num = atoi(return_code);
-        char *callbacks     = strsep( &value, ":" );
+        return_code         = strsep( &value, ":" );
+        return_code_num     = atoi(return_code);
+        callbacks           = strsep( &value, ":" );
         if(strlen(export_queue) > 50) {
             gm_log( GM_LOG_ERROR, "export queue name '%s' is too long, please use a maximum of 50 characters\n", export_queue );
         } else {
             while ( (callback = strsep( &callbacks, "," )) != NULL ) {
-                int callback_num = atoi(trim(callback));
+                callback_num = atoi(trim(callback));
                 if(index(callback, 'N') != NULL) {
                     callback_num = -1;
                     /* get neb callback number by name */
-                    int i;
                     for(i=0;i<GM_NEBTYPESSIZE;i++) {
-                        char * type = nebcallback2str(i);
+                        type = nebcallback2str(i);
                         if(!strcmp(type, callback)) {
                             callback_num = i;
                         }
@@ -756,7 +787,7 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
                     }
                 }
 
-                int number = opt->exports[callback_num]->elem_number;
+                number = opt->exports[callback_num]->elem_number;
                 opt->exports[callback_num]->name[number]        = strdup(export_queue);
                 opt->exports[callback_num]->return_code[number] = return_code_num;
                 opt->exports[callback_num]->elem_number++;
@@ -872,6 +903,7 @@ void dumpconfig(mod_gm_opt_t *opt, int mode) {
 #endif
     }
     if(mode == GM_NEB_MODE) {
+        gm_log( GM_LOG_DEBUG, "queue by cust var:   %s\n", opt->queue_cust_var == NULL ? "no" : opt->queue_cust_var);
         gm_log( GM_LOG_DEBUG, "debug result:        %s\n", opt->debug_result == GM_ENABLED ? "yes" : "no");
         gm_log( GM_LOG_DEBUG, "result_worker:       %d\n", opt->result_workers);
         gm_log( GM_LOG_DEBUG, "do_hostchecks:       %s\n", opt->do_hostchecks == GM_ENABLED ? "yes" : "no");
@@ -936,9 +968,9 @@ void dumpconfig(mod_gm_opt_t *opt, int mode) {
 
 /* free options structure */
 void mod_gm_free_opt(mod_gm_opt_t *opt) {
+    int i,j;
     if(opt == NULL)
         return;
-    int i,j;
     for(i=0;i<opt->server_num;i++) {
         free(opt->server_list[i]->host);
         free(opt->server_list[i]);
@@ -969,6 +1001,7 @@ void mod_gm_free_opt(mod_gm_opt_t *opt) {
     free(opt->host);
     free(opt->service);
     free(opt->identifier);
+    free(opt->queue_cust_var);
 #ifdef EMBEDDEDPERL
     free(opt->p1_file);
 #endif
@@ -1182,8 +1215,6 @@ void escape(char *out, int ch) {
             strcpy(out, "\\a"); break;
         case '\\':
             strcpy(out, "\\\\"); break;
-        //case '\'':
-        //    strcpy(out, "\\\'"); break;
         case '\"':
             strcpy(out, "\\\""); break;
         default:
@@ -1600,8 +1631,8 @@ void send_result_back(gm_job_t * exec_job) {
     temp_buffer1[0]='\x0';
     snprintf( temp_buffer1, sizeof( temp_buffer1 )-1, "host_name=%s\ncore_start_time=%i.%i\nstart_time=%i.%i\nfinish_time=%i.%i\nreturn_code=%i\nexited_ok=%i\n",
               exec_job->host_name,
-              ( int )exec_job->core_start_time.tv_sec,
-              ( int )exec_job->core_start_time.tv_usec,
+              ( int )exec_job->next_check.tv_sec,
+              ( int )exec_job->next_check.tv_usec,
               ( int )exec_job->start_time.tv_sec,
               ( int )exec_job->start_time.tv_usec,
               ( int )exec_job->finish_time.tv_sec,
@@ -1662,7 +1693,9 @@ void send_result_back(gm_job_t * exec_job) {
     }
 
     if( mod_gm_opt->dupserver_num ) {
-        strncpy(temp_buffer2, "type=passive\n", (sizeof(temp_buffer1)-2));
+        if(mod_gm_opt->dup_results_are_passive) {
+            strncpy(temp_buffer2, "type=passive\n", (sizeof(temp_buffer1)-2));
+        }
         strncat(temp_buffer2, temp_buffer1, (sizeof(temp_buffer2)-2));
         temp_buffer2[sizeof( temp_buffer2 )-1]='\x0';
         if( add_job_to_queue( current_client_dup,
@@ -1707,6 +1740,7 @@ char *md5sum(char *text) {
 
 /* add parsed server to list */
 void add_server(int * server_num, gm_server_t * server_list[GM_LISTSIZE], char * servername) {
+    gm_server_t *new_server;
     char * server   = strdup( servername );
     char * server_c = server;
     char * host     = strsep( &server, ":" );
@@ -1715,7 +1749,6 @@ void add_server(int * server_num, gm_server_t * server_list[GM_LISTSIZE], char *
     if(port_val != NULL) {
         port  = ( in_port_t ) atoi( port_val );
     }
-    gm_server_t *new_server;
     new_server = malloc(sizeof(gm_server_t));
     if(!strcmp(host, "")) {
         new_server->host = strdup("localhost");
