@@ -11,6 +11,7 @@
 #ifdef EMBEDDEDPERL
 #include <epn_utils.h>
 #endif
+#include "gearman_utils.h"
 
 mod_gm_opt_t *mod_gm_opt;
 
@@ -63,7 +64,11 @@ int main (int argc, char **argv, char **env) {
     rrc = real_exit_code(run_check(cmd, &result, &error));
     //diag(result);
     cmp_ok(rrc, "==", 3, "cmd '%s' returned rc %d", cmd, rrc);
-    like(result, "sending job to gearmand failed:", "result");
+    if(atof(gearman_version()) >= 0.31) {
+        like(result, "send_gearman UNKNOWN:", "result");
+    } else {
+        like(result, "sending job to gearmand failed:", "result");
+    }
     free(result);
     free(error);
 
@@ -75,7 +80,11 @@ int main (int argc, char **argv, char **env) {
     rrc = real_exit_code(run_check(cmd, &result, &error));
     //diag(result);
     cmp_ok(rrc, "==", 3, "cmd '%s' returned rc %d", cmd, rrc);
-    like(result, "sending job to gearmand failed:", "result");
+    if(atof(gearman_version()) >= 0.31) {
+        like(result, "send_multi UNKNOWN:", "result");
+    } else {
+        like(result, "sending job to gearmand failed:", "result");
+    }
     free(result);
     free(error);
 
